package com.link.core.converter;

import com.link.core.converter.i18n.DefaultStringValue;
import com.link.core.converter.i18n.Resources;
import java.text.MessageFormat;

public class EnumConverters {
   public static <E extends Enum> Converter<E, String> toString(Class<E> enumType) {
      return new Converter<E, String>() {
         public String convert(E source) throws ConversionException {
            return source == null ? null : source.name();
         }
      };
   }

   public static <E extends Enum> Converter<E, Integer> toInteger(Class<E> enumType) {
      return new Converter<E, Integer>() {
         public Integer convert(E source) throws ConversionException {
            return source == null ? null : source.ordinal();
         }
      };
   }

   public static <E extends Enum> Converter<Object, E> toEnum(final Class<E> enumType) {
      return new Converter<Object, E>() {
         public E convert(Object source) throws ConversionException {
            if (source == null) {
               return null;
            } else if (source instanceof String) {
               return Enum.valueOf(enumType, (String)source);
            } else if (source instanceof Integer) {
               return ((Enum[])enumType.getEnumConstants())[(Integer)source];
            } else {
               throw new ConversionException(MessageFormat.format(EnumConverters.R.R.unsupportsSourceType(), source.getClass()), new Object[0]);
            }
         }
      };
   }

   public interface R {
      R R = (R)Resources.create(R.class);

      @DefaultStringValue("不支持的源类型：{0}")
      String unsupportsSourceType();
   }
}
